/************************************************************/
/*   Fonctions de mise en oeuvre du SPI en mode matre      */
/************************************************************/
// ATmega164p
// le 27 11 08
#include "ATmega164_VMG.h"

// Initialisation du SPI en mode matre
// ------------------------------------
// SPI2X SPR1 SPR0  SCK frequency
//  0     0    0    fCPU/4
//  0     0    1    fCPU/16
//  0     1    0    fCPU/64
//  0     1    1    fCPU/128
//  1     0    0    fCPU/2
//  1     0    1    fCPU/8
//  1     1    0    fCPU/32
//  1     1    1    fCPU/64

void Init_SPI (char division)
     {
     // SS, SCK et MOSI configures en sorties au niveau bas
     DDRB |= (1<<SS)+(1<<MOSI)+(1<<SCK);
     PORTB &=~((1<<SS)+(1<<MOSI)+(1<<SCK));
     switch (division)
          {
          case 2 :       SPCR = 0;
                         SPSR = (1<<SPI2X);
                         break;
          case 4 :       SPCR = 0;
                         break;
          case 8 :       SPCR = 1;
                         SPSR = (1<<SPI2X);
                         break;
          case 16 :      SPCR = 1;
                         break;
          case 32 :      SPCR = 2;
                         SPSR = (1<<SPI2X);
                         break;
          case 64 :      SPCR = 2;
                         break;
          case 128 :     SPCR = 3;
                         break;
          }
     SPCR |= (1<<SPE)+(1<<MSTR);   // mode matre, MSB en premier (DORD = 0)
                                   // mode 00 : CPOL = 0, CPHA = 0
     SPDR = 0;                     // Emission d'initialisation du SPI
     }

// Emission d'un octet
// -------------------
void Tx_SPI (byte tx_reg)
     {
     while (!(SPSR & (1<<SPIF)));  // Attente octet prcdent mis
     SPDR = tx_reg;      // Ecriture dans SPDR provoque RaZ de SPIF
     }

